<?php
/**
 * Plugin Name: Nutrition Facts Label Creator
 * Author:      SaurabhSharma
 * Author URI: 	http://codecanyon.net/user/saurabhsharma
 * Version:     1.2.0
 * Text Domain: nflc
 * Domain Path: /languages/
 * Description: A Visual Composer add-on for generating Nutrition Facts Label
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Nutrition_Facts_Label_Creator' ) ) {

	class Nutrition_Facts_Label_Creator {

		public $vct_prefix = 'nflc';

		function __construct() {

			// Include required files
			add_action( 'plugins_loaded', array( &$this, 'nflc_includes' ) );

			// Load translation, scripts and shortcodes
			add_action( 'init', array( &$this, 'nflc_init' ) );

			// VC Specific
			add_action( 'vc_before_init', array( &$this, 'nflc_map_shortcode_to_vc' ) );
			//add_action( 'after_setup_theme', array( &$this, 'nflc_add_vc_templates' ) );
			add_action( 'admin_notices',  array( &$this, 'nflc_install_vc_notice' ) );

		}
		
		// Show notice if Visual Composer not installed
		function nflc_install_vc_notice() {
			if ( ! class_exists( 'Vc_Manager' ) ) {
				printf( '<div class="error"><p>%s</p></div>', esc_attr__( 'Nutrition Facts Label Creator plugin requires Visual Composer plugin to work correctly. Kindly install and activate WPBakery Visual Composer plugin.', 'nflc' ) );
			}
			else {
				return;
			}
		}

		// Include required files
		function nflc_includes() {
			$plugin_dir = trailingslashit( plugin_dir_path( __FILE__ ) );

			if ( class_exists ( 'Vc_Manager' ) ) {
				require_once( $plugin_dir . 'includes/nflc_functions.php' );
			}
		}

		// Init function
		function nflc_init() {

			// Translation
			load_plugin_textdomain( 'nflc', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );

			if ( ! is_admin() ) {

				wp_enqueue_style( 'nflc-plugin-css', plugin_dir_url( __FILE__ ) . 'assets/css/nflc_frontend.css', array(), null );

				if ( is_rtl() ) {
					wp_register_style( 'nflc-plugin-rtl', plugin_dir_url( __FILE__ ) . 'assets/css/rtl_nflc_frontend.css', array(), null );
					wp_enqueue_style( 'nflc-plugin-rtl' );
				}

			}

			// Add shortcodes
			add_shortcode( 'nflc', array( $this, 'nflc' ) );
		}

		// Map shortcodes to Visual Composer
		function nflc_map_shortcode_to_vc() {

			// Let plugin text domain load for vc_map
			load_plugin_textdomain( 'nflc', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
			
			// [nflc]
			vc_map(
				array(
					'name' => __( 'Nutrition Facts Label Creator', 'nflc' ),
					'base' => 'nflc',
					'icon' =>  plugin_dir_url( __FILE__ ) . 'assets/images/nflc_icon.png',
					'show_settings_on_create' => false,
					'description' => __( 'Create Nutrition Facts Label with ease', 'nflc' ),
					'params' => array(

						// General Tab
						array(
							'heading' => __( 'Nutrition facts label heading', 'nflc' ),
							'param_name' => 'nutri_heading',
							'type' => 'textfield',
							'std' => __( 'Nutrition Facts', 'nflc' ),
							'description' => __( 'Provide a heading for nutrition facts table.', 'nflc' ),
							'group' => __( 'General', 'nflc' )
						),
												
						array(
							'heading' => __( 'Nutrition table style', 'nflc' ),
							'type' => 'dropdown',
							'param_name' => 'display_style',
							'value' => array(
									__( 'Standard', 'nflc' )  => 'std',
									__( 'Flat', 'nflc' )  => 'flat',
									__( 'Flat Striped', 'nflc' )  => 'flat striped',
									__( 'Classic', 'nflc' )  => 'classic',
									__( 'Classic Tabular', 'nflc' )  => 'classic tabular',
									__( 'Lined', 'nflc' )  => 'lined'
							),
							'std' => 'std',
							'description' => __( 'Select a style for Nutrition table.', 'nflc' ),
							'group' => __( 'General', 'nflc' )
						),
						
						array(
							'param_name' => 'show_dv',
							'heading' => __( 'Show standard Daily Values', 'nflc' ),
							'type' => 'checkbox',
							'value' => array( __( 'Show standard Daily Values', 'nflc' ) => 'true' ),
							'description' => __( 'Enabling this option will show standard Daily Values in the chart.', 'nflc' ),
							'group' => __( 'General', 'nflc' )
						),

						array(
							'heading' => __( 'Nutrition label extra notes', 'nflc' ),
							'param_name' => 'extra_notes',
							'type' => 'textarea',
							'std' => __( '* The % Daily Value (DV) tells you how much a nutrient in
a serving of food contributes to a daily diet. 2,000 calories
a day is used for general nutrition advice.', 'nflc' ),
							'description' => __( 'Provide extra notes for the Nutrition table. This will be displayed at the end of table.', 'nflc' ),
							'group' => __( 'General', 'nflc' )
						),
						
						array(
							'heading' => __( 'Extra Class', 'nflc' ),
							'param_name' => 'xclass',
							'type' => 'textfield',
							'std' => '',
							'description' => __( 'Any extra class you wish to add to the generated table.', 'nflc' ),
							'group' => __( 'General', 'nflc' )
						),
						

						// Nutrition tab
						array(
							'heading' => __( 'Serving Size', 'nflc' ),
							'param_name' => 'serving_size',
							'type' => 'textfield',
							'std' => '',
							'description' => __( 'Provide a serving size per container. E.g. 1 Cookie(20g), or 100g', 'nflc' ),
							'group' => __( 'Nutrition', 'nflc' )
						),
						
						array(
							'heading' => __( 'Serving Per Container', 'nflc' ),
							'param_name' => 'serving_per_cont',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'Provide serving per container. E.g. 30', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Calorie per serving (cal)', 'nflc' ),
							'param_name' => 'calories',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'Provide approximate calories (without unit) per serving. E.g. 240', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',							
							'group' => __( 'Nutrition', 'nflc' )
						),						

						array(
							'heading' => __( 'Total Fat', 'nflc' ),
							'param_name' => 'total_fat',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Total Fat (g), without unit. Standard daily value is 78 g', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Saturated Fat', 'nflc' ),
							'param_name' => 'saturated_fat',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Saturated Fat (g), without unit. Standard daily value is 20 g', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Trans Fat', 'nflc' ),
							'param_name' => 'trans_fat',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Trans Fat (g), without unit. ', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Polyunsaturated Fat', 'nflc' ),
							'param_name' => 'polyunsat_fat',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Polyunsaturated Fat (g), without unit. ', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Monounsaturated Fat', 'nflc' ),
							'param_name' => 'monounsat_fat',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Monounsaturated Fat (g), without unit. ', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Cholesterol', 'nflc' ),
							'param_name' => 'cholesterol',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Cholesterol (mg), without unit. Standard daily value is 300 mg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Sodium', 'nflc' ),
							'param_name' => 'sodium',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Sodium (mg), without unit. Standard daily value is 2300 mg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Total Carbohydrate', 'nflc' ),
							'param_name' => 'carbohydrate',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Total Carbohydrate (g), without unit. Standard daily value is 275 g', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Dietary Fiber', 'nflc' ),
							'param_name' => 'fiber',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Dietary Fiber (g), without unit. Standard daily value is 28 g', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Total Sugars', 'nflc' ),
							'param_name' => 'sugar',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Total Sugars (g), without unit. ', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Added Sugars', 'nflc' ),
							'param_name' => 'added_sugar',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Added Sugars (g), without unit. Standard daily value is 50 g', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Sugar Alcohal', 'nflc' ),
							'param_name' => 'sugar_alcohal',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Sugar Alcohal (g), without unit. ', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Protein', 'nflc' ),
							'param_name' => 'protein',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Protein (g), without unit. Standard daily value is 50 g', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Vitamin D (Cholecalciferol)', 'nflc' ),
							'param_name' => 'vitamin_d',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Vitamin D (Cholecalciferol) (IU), without unit. Standard daily value is 15mcg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Calcium', 'nflc' ),
							'param_name' => 'calcium',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Calcium (mg), without unit. Standard daily value is 1300 mg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Iron', 'nflc' ),
							'param_name' => 'iron',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Iron (mg), without unit. Standard daily value is 18 mg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Potassium', 'nflc' ),
							'param_name' => 'potassium',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Potassium (mg), without unit. Standard daily value is 4700 mg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Vitamin A', 'nflc' ),
							'param_name' => 'vitamin_a',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Vitamin A (International Units), without unit. Standard daily value is 900 mcg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Vitamin C (Ascorbic Acid)', 'nflc' ),
							'param_name' => 'vitamin_c',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Vitamin C (Ascorbic Acid) (mg), without unit. Standard daily value is 90 mg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Vitamin E (Tocopherol)', 'nflc' ),
							'param_name' => 'vitamin_e',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Vitamin E (Tocopherol) (IU), without unit. Standard daily value is 15 mg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Vitamin K', 'nflc' ),
							'param_name' => 'vitamin_k',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Vitamin K (mcg), without unit. Standard daily value is 120 mcg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Vitamin B1 (Thiamin)', 'nflc' ),
							'param_name' => 'vitamin_b1',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Vitamin B1 (Thiamin) (mg), without unit. Standard daily value is 1.2 mg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Vitamin B2 (Riboflavin)', 'nflc' ),
							'param_name' => 'vitamin_b2',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Vitamin B2 (Riboflavin) (mg), without unit. Standard daily value is 1.3 mg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Vitamin B3 (Niacin)', 'nflc' ),
							'param_name' => 'vitamin_b3',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Vitamin B3 (Niacin) (mg), without unit. Standard daily value is 16 mg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Vitamin B6 (Pyridoxine)', 'nflc' ),
							'param_name' => 'vitamin_b6',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Vitamin B6 (Pyridoxine) (mg), without unit. Standard daily value is 1.3 mg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Folate', 'nflc' ),
							'param_name' => 'folate',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Folate (mcg), without unit. Standard daily value is 400 mcg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Vitamin B12 (Cobalamine)', 'nflc' ),
							'param_name' => 'vitamin_b12',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Vitamin B12 (Cobalamine) (mcg), without unit. Standard daily value is 2.4 mcg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Biotin', 'nflc' ),
							'param_name' => 'biotin',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Biotin (mcg), without unit. Standard daily value is 30 mcg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Vitamin B5 (Pantothenic acid)', 'nflc' ),
							'param_name' => 'vitamin_b5',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Vitamin B5 (Pantothenic acid) (mg), without unit. Standard daily value is 5 mg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Phosphorus', 'nflc' ),
							'param_name' => 'phosphorus',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Phosphorus (mg), without unit. Standard daily value is 700 mg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Iodine', 'nflc' ),
							'param_name' => 'iodine',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Iodine (mcg), without unit. Standard daily value is 150 mcg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Magnesium', 'nflc' ),
							'param_name' => 'magnesium',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Magnesium (mg), without unit. Standard daily value is 400 mg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Zinc', 'nflc' ),
							'param_name' => 'zinc',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Zinc (mg), without unit. Standard daily value is 11 mg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Selenium', 'nflc' ),
							'param_name' => 'selenium',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Selenium (mcg), without unit. Standard daily value is 55 mcg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Copper', 'nflc' ),
							'param_name' => 'copper',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Copper (mg), without unit. Standard daily value is 0.9 mg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Manganese', 'nflc' ),
							'param_name' => 'manganese',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Manganese (mg), without unit. Standard daily value is 2.3 mg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Chromium', 'nflc' ),
							'param_name' => 'chromium',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Chromium (mcg), without unit. Standard daily value is 35 mcg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Molybdenum', 'nflc' ),
							'param_name' => 'molybdenum',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Molybdenum (mcg), without unit. Standard daily value is 45 mcg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),

						array(
							'heading' => __( 'Chloride', 'nflc' ),
							'param_name' => 'chloride',
							'type' => 'textfield_num',
							'min'	=> '0',
							'std' => '',
							'description' => __( 'The amount of Chloride (mg), without unit. Standard daily value is 2300 mg', 'nflc' ),
							'edit_field_class' => 'vc_col-sm-6 vc_column',
							'group' => __( 'Nutrition', 'nflc' )
						),
						
						// Custom Nutrients
						array(
							'type' => 'param_group',
							'value' => urlencode(
										json_encode(
											array(
												array(
													'name' => '',
													'unit' => '',
													'amt' => '',
													'sv' => '',
													'level' => '',
													'text_style' => ''
												)
											)
										)
									),
							'param_name' => 'custom_nutrients',
							// Sub params of a group item
							'params' => array(
								array(
									'type' => 'textfield',
									'value' => '',
									'heading' => __( 'Nutrient name', 'nflc' ),
									'param_name' => 'name',
									'description' => __( 'Provide a nutrient name. E.g. Power Protein', 'nflc' ),
									'admin_label' => true
								),
								
								array(
									'type' => 'textfield',
									'value' => '',
									'heading' => __( 'Nutrient Quantity Unit', 'nflc' ),
									'param_name' => 'unit',
									'description' => __( 'Provide a nutrient unit. E.g. mg', 'nflc' )
								),
								
								array(
									'type' => 'textfield',
									'value' => '',
									'heading' => __( 'Amount per serving', 'nflc' ),
									'param_name' => 'amt',
									'description' => __( 'Provide amount per serving (without unit). E.g. 20', 'nflc' )
								),
								
								array(
									'type' => 'textfield',
									'value' => '',
									'heading' => __( 'Standard daily value', 'nflc' ),
									'param_name' => 'sv',
									'description' => __( 'Provide standard daily value of Nutrient (without unit). E.g. 200', 'nflc' )
								),
								
								array(
									'heading' => __( 'Nutrient indent level', 'nflc' ),
									'type' => 'dropdown',
									'param_name' => 'level',
									'value' => array(
										__( 'Level 0', 'nflc' ) => '0',
										__( 'Level 1', 'nflc' ) => '1',
										__( 'Level 2', 'nflc' ) => '2',
										__( 'Level 3', 'nflc' ) => '3'
									),
									'std' => '',
									'description' => __( 'Select indent level for Nutrient entry in table.', 'nflc' )
								),
								
								array(
									'heading' => __( 'Nutrient text style', 'nflc' ),
									'type' => 'dropdown',
									'param_name' => 'text_style',
									'value' => array(
										__( 'Normal', 'nflc' ) => 'normal',
										__( 'Bold', 'nflc' ) => 'bold'
									),
									'std' => '',
									'description' => __( 'Select text style for the nutrient entry.', 'nflc' )
								),
							),
							'group' => __( 'Add Nutrients', 'nflc' )
						)					
					),
				)
			); // [nflc]			
		}


		// The [nflc] shortcode function
		function nflc( $atts, $content = null ) {
			extract( shortcode_atts( array(
				'display_style'			=> 'std',
				
				// Nutrition facts
				'serving_per_cont'	=> '',
				'serving_size'		=> '',
				'calories'			=> '',
				'nutri_heading'		=> __( 'Nutrition Facts', 'nflc' ),
				'extra_notes'		=> __( '*Percent Daily Values are based on a 2,000 calorie diet. Your daily values may be higher or lower depending on your calorie needs.', 'nflc' ),
				'show_dv'			=> false,
				'xclass'			=> '',
				'custom_nutrients' 	=> '',

				// Nutrients
				'total_fat'			=> '',
				'saturated_fat'		=> '',
				'trans_fat'			=> '',
				'polyunsat_fat'		=> '',
				'monounsat_fat'		=> '',
				'cholesterol'		=> '',
				'sodium'			=> '',
				'carbohydrate'		=> '',
				'fiber'				=> '',
				'sugar'				=> '',
				'added_sugar'		=> '',
				'sugar_alcohal'		=> '',
				'protein'			=> '',
				'vitamin_d'			=> '',
				'calcium'			=> '',
				'iron'				=> '',
				'potassium'			=> '',
				'vitamin_a'			=> '',
				'vitamin_c'			=> '',
				'vitamin_e'			=> '',
				'vitamin_k'			=> '',
				'vitamin_b1'		=> '',
				'vitamin_b2'		=> '',
				'vitamin_b3'		=> '',
				'vitamin_b6'		=> '',
				'folate'			=> '',
				'vitamin_b12'		=> '',
				'biotin'			=> '',
				'vitamin_b5'		=> '',
				'phosphorus'		=> '',
				'iodine'			=> '',
				'magnesium'			=> '',
				'zinc'				=> '',
				'selenium'			=> '',
				'copper'			=> '',
				'manganese'			=> '',
				'chromium'			=> '',
				'molybdenum'		=> '',
				'chloride'			=> ''
			), $atts ) );

			// Nutrition values
			$nutrition_facts = apply_filters( 'nflc_nutrition_facts_list', array(
				array(
					'id'			=> 'total_fat',
					'label'			=> __( 'Total Fat', 'nflc' ),
					'schema'		=> 'fatContent',
					'liclass'		=> false,
					'labelclass'	=> 'font-bold',
					'sv'			=> apply_filters( 'total_fat_sv', 78 ),
					'unit'			=> 'g'
				),
				array(
					'id'			=> 'saturated_fat',
					'label'			=> __( 'Saturated Fat', 'nflc' ),
					'schema'		=> 'saturatedFatContent',
					'liclass'		=> 'nt-sublevel-1',
					'labelclass'	=> false,
					'sv'			=> apply_filters( 'saturated_fat_sv', 20 ),
					'unit'			=> 'g'
				),
				array(
					'id'			=> 'trans_fat',
					'label'			=> __( 'Trans Fat', 'nflc' ),
					'schema'		=> 'transFatContent',
					'liclass'		=> 'nt-sublevel-1',
					'labelclass'	=> false,
					'sv'			=> false,
					'unit'			=> 'g'
				),
				array(
					'id'			=> 'polyunsat_fat',
					'label'			=> __( 'Polyunsaturated Fat', 'nflc' ),
					'schema'		=> 'unsaturatedFatContent',
					'liclass'		=> 'nt-sublevel-1',
					'labelclass'	=> false,
					'sv'			=> false,
					'unit'			=> 'g'
				),
				array(
					'id'			=> 'monounsat_fat',
					'label'			=> __( 'Monounsaturated Fat', 'nflc' ),
					'schema'		=> 'unsaturatedFatContent',
					'liclass'		=> 'nt-sublevel-1',
					'labelclass'	=> false,
					'sv'			=> false,
					'unit'			=> 'g'
				),
				array(
					'id'			=> 'cholesterol',
					'label'			=> __( 'Cholesterol', 'nflc' ),
					'schema'		=> 'cholesterolContent',
					'liclass'		=> '',
					'labelclass'	=> 'font-bold',
					'sv'			=> apply_filters( 'cholesterol_sv', 300 ),
					'unit'			=> 'mg'
				),
				array(
					'id'			=> 'sodium',
					'label'			=> __( 'Sodium', 'nflc' ),
					'schema'		=> 'sodiumContent',
					'liclass'		=> '',
					'labelclass'	=> 'font-bold',
					'sv'			=> apply_filters( 'sodium_sv', 2300 ),
					'unit'			=> 'mg'
				),
				array(
					'id'			=> 'carbohydrate',
					'label'			=> __( 'Total Carbohydrate', 'nflc' ),
					'schema'		=> 'carbohydrateContent',
					'liclass'		=> '',
					'labelclass'	=> 'font-bold',
					'sv'			=> apply_filters( 'carbohydrate_sv', 275 ),
					'unit'			=> 'g'
				),
				array(
					'id'			=> 'fiber',
					'label'			=> __( 'Dietary Fiber', 'nflc' ),
					'schema'		=> 'fiberContent',
					'liclass'		=> 'nt-sublevel-1',
					'labelclass'	=> '',
					'sv'			=> apply_filters( 'fiber_sv', 28 ),
					'unit'			=> 'g'
				),
				array(
					'id'			=> 'sugar',
					'label'			=> __( 'Total Sugars', 'nflc' ),
					'schema'		=> 'sugarContent',
					'liclass'		=> 'nt-sublevel-1',
					'labelclass'	=> '',
					'sv'			=> false,
					'unit'			=> 'g'
				),
				array(
					'id'			=> 'added_sugar',
					'label'			=> __( 'Added Sugars', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> 'nt-sublevel-2',
					'labelclass'	=> '',
					'sv'			=> apply_filters( 'added_sugar_sv', 50 ),
					'unit'			=> 'g'
				),
				array(
					'id'			=> 'sugar_alcohal',
					'label'			=> __( 'Sugar Alcohal', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> 'nt-sublevel-1',
					'labelclass'	=> '',
					'sv'			=> false,
					'unit'			=> 'g'
				),
				array(
					'id'			=> 'protein',
					'label'			=> __( 'Protein', 'nflc' ),
					'schema'		=> 'proteinContent',
					'liclass'		=> 'nt-sep sep-8',
					'labelclass'	=> 'font-bold',
					'sv'			=> apply_filters( 'protein_sv', 50 ),
					'unit'			=> 'g'
				),
				array(
					'id'			=> 'vitamin_d',
					'label'			=> __( 'Vitamin D (Cholecalciferol)', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> false,
					'labelclass'	=> false,
					'sv'			=> apply_filters( 'vitamin_d_sv', 15 ),
					'unit'			=> 'mcg'
				),
				array(
					'id'			=> 'calcium',
					'label'			=> __( 'Calcium', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> false,
					'labelclass'	=> false,
					'sv'			=> apply_filters( 'calcium_sv', 1300 ),
					'unit'			=> 'mg'
				),
				array(
					'id'			=> 'iron',
					'label'			=> __( 'Iron', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> false,
					'labelclass'	=> false,
					'sv'			=> apply_filters( 'iron_sv', 18 ),
					'unit'			=> 'mg'
				),
				array(
					'id'			=> 'potassium',
					'label'			=> __( 'Potassium', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> false,
					'labelclass'	=> false,
					'sv'			=> apply_filters( 'potassium_sv', 4700 ),
					'unit'			=> 'mg'
				),
				array(
					'id'			=> 'vitamin_a',
					'label'			=> __( 'Vitamin A', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> false,
					'labelclass'	=> false,
					'sv'			=> apply_filters( 'vitamin_a_sv', 900 ),
					'unit'			=> 'mcg'
				),
				array(
					'id'			=> 'vitamin_c',
					'label'			=> __( 'Vitamin C (Ascorbic Acid)', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> false,
					'labelclass'	=> false,
					'sv'			=> apply_filters( 'vitamin_c_sv', 90 ),
					'unit'			=> 'mg'
				),
				array(
					'id'			=> 'vitamin_e',
					'label'			=> __( 'Vitamin E (Tocopherol)', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> false,
					'labelclass'	=> false,
					'sv'			=> apply_filters( 'vitamin_e_sv', 15 ),
					'unit'			=> 'mg'
				),
				array(
					'id'			=> 'vitamin_k',
					'label'			=> __( 'Vitamin K', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> false,
					'labelclass'	=> false,
					'sv'			=> apply_filters( 'vitamin_k_sv', 120 ),
					'unit'			=> 'mcg'
				),
				array(
					'id'			=> 'vitamin_b1',
					'label'			=> __( 'Vitamin B1 (Thiamin)', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> false,
					'labelclass'	=> false,
					'sv'			=> apply_filters( 'vitamin_b1_sv', 1.2 ),
					'unit'			=> 'mg'
				),
				array(
					'id'			=> 'vitamin_b2',
					'label'			=> __( 'Vitamin B2 (Riboflavin)', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> false,
					'labelclass'	=> false,
					'sv'			=> apply_filters( 'vitamin_b2_sv', 1.3 ),
					'unit'			=> 'mg'
				),
				array(
					'id'			=> 'vitamin_b3',
					'label'			=> __( 'Vitamin B3 (Niacin)', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> false,
					'labelclass'	=> false,
					'sv'			=> apply_filters( 'vitamin_b3_sv', 16 ),
					'unit'			=> 'mg'
				),
				array(
					'id'			=> 'vitamin_b6',
					'label'			=> __( 'Vitamin B6 (Pyridoxine)', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> false,
					'labelclass'	=> false,
					'sv'			=> apply_filters( 'vitamin_b6_sv', 1.3 ),
					'unit'			=> 'mg'
				),
				array(
					'id'			=> 'folate',
					'label'			=> __( 'Folate', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> false,
					'labelclass'	=> false,
					'sv'			=> apply_filters( 'folate_sv', 400 ),
					'unit'			=> 'mcg'
				),
				array(
					'id'			=> 'vitamin_b12',
					'label'			=> __( 'Vitamin B12 (Cobalamine)', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> false,
					'labelclass'	=> false,
					'sv'			=> apply_filters( 'vitamin_b12_sv', 2.4 ),
					'unit'			=> 'mcg'
				),
				array(
					'id'			=> 'biotin',
					'label'			=> __( 'Biotin', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> false,
					'labelclass'	=> false,
					'sv'			=> apply_filters( 'biotin_sv', 30 ),
					'unit'			=> 'mcg'
				),
				array(
					'id'			=> 'vitamin_b5',
					'label'			=> __( 'Vitamin B5 (Pantothenic acid)', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> false,
					'labelclass'	=> false,
					'sv'			=> apply_filters( 'vitamin_b5_sv', 5 ),
					'unit'			=> 'mg'
				),
				array(
					'id'			=> 'phosphorus',
					'label'			=> __( 'Phosphorus', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> false,
					'labelclass'	=> false,
					'sv'			=> apply_filters( 'phosphorus_sv', 700 ),
					'unit'			=> 'mg'
				),
				array(
					'id'			=> 'iodine',
					'label'			=> __( 'Iodine', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> false,
					'labelclass'	=> false,
					'sv'			=> apply_filters( 'iodine_sv', 150 ),
					'unit'			=> 'mcg'
				),
				array(
					'id'			=> 'magnesium',
					'label'			=> __( 'Magnesium', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> false,
					'labelclass'	=> false,
					'sv'			=> apply_filters( 'magnesium_sv', 400 ),
					'unit'			=> 'mg'
				),
				array(
					'id'			=> 'zinc',
					'label'			=> __( 'Zinc', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> false,
					'labelclass'	=> false,
					'sv'			=> apply_filters( 'zinc_sv', 11 ),
					'unit'			=> 'mg'
				),
				array(
					'id'			=> 'selenium',
					'label'			=> __( 'Selenium', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> false,
					'labelclass'	=> false,
					'sv'			=> apply_filters( 'selenium_sv', 55 ),
					'unit'			=> 'mcg'
				),
				array(
					'id'			=> 'copper',
					'label'			=> __( 'Copper', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> false,
					'labelclass'	=> false,
					'sv'			=> apply_filters( 'copper_sv', .9 ),
					'unit'			=> 'mg'
				),
				array(
					'id'			=> 'manganese',
					'label'			=> __( 'Manganese', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> false,
					'labelclass'	=> false,
					'sv'			=> apply_filters( 'manganese_sv', 2.3 ),
					'unit'			=> 'mg'
				),
				array(
					'id'			=> 'chromium',
					'label'			=> __( 'Chromium', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> false,
					'labelclass'	=> false,
					'sv'			=> apply_filters( 'chromium_sv', 35 ),
					'unit'			=> 'mcg'
				),
				array(
					'id'			=> 'molybdenum',
					'label'			=> __( 'Molybdenum', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> false,
					'labelclass'	=> false,
					'sv'			=> apply_filters( 'molybdenum_sv', 45 ),
					'unit'			=> 'mcg'
				),
				array(
					'id'			=> 'chloride',
					'label'			=> __( 'Chloride', 'nflc' ),
					'schema'		=> false,
					'liclass'		=> 'nt-sep',
					'labelclass'	=> false,
					'sv'			=> apply_filters( 'chloride_sv', 2300 ),
					'unit'			=> 'mg'
				)
			) );

			ob_start();

			$template_path = apply_filters( 'nflc_template_path', '/nflc_templates/' );

			if ( locate_template( $template_path . 'default.php' ) ) {
				require( get_stylesheet_directory() . $template_path . 'default.php' );
			}
			else {
				require( dirname( __FILE__ ) . $template_path . 'default.php' );
			}

			$out = ob_get_contents();

			ob_end_clean();

			return $out;

		}

		function nflc_add_vc_templates() {
		    global $vct_prefix;

		    // Remove default templates
		    add_filter( 'vc_load_default_templates', function( $templates ) use ( $vct_prefix ) {
		        if ( apply_filters( "{$vct_prefix}_disable_builtin_templates", false ) ) {
		            return array();
				}
		        else {
		            return $templates;
				}
		    }, 11 );

		    // Add custom template
		    add_filter( 'vc_load_default_templates', function( $templates ) use ( $vct_prefix ) {
		        // Load templates from plugin /vc_templates directory
		        $templates = array_merge( $templates, $this->nflc_load_vc_templates(__DIR__ . "/vc_templates/*.php", 'vctm' ) );

		        // Load templates from theme
		        $templates = array_merge( $templates, $this->nflc_load_vc_templates( trailingslashit( get_stylesheet_directory() ) . 'vc_templates/*.php', 'theme' ) );

		        //Load additional templates from plugins or themes
		        foreach( apply_filters( "{$vct_prefix}_template_locations", array() ) as $additional_location )
		            $templates = array_merge( $templates, $this->nflc_load_vc_templates( trailingslashit( $additional_location ) . '*.php', 'plugin' ) );

		        return $templates;
		    }, 12 );
		}

		function nflc_load_vc_templates( $folder = 'default_templates', $hook_prefix = 'vctm' ) {
		    global $vct_prefix;

		    $templates = array();

		    //Load default tempaltes
		    foreach( glob( $folder ) as $filename ) {
		        $filename_clean = basename( $filename, '.php' );

		        $data = array();
		        $data['name']       = __( apply_filters( "{$vct_prefix}_{$hook_prefix}_name_{$filename_clean}", $this->nflc_prettify_name( $filename_clean ) ), apply_filters("{$vct_prefix}_textdomain", 'vc_template_manager' ) );
		        $data['weight']     = apply_filters( "{$vct_prefix}_{$hook_prefix}_weight_{$filename_clean}", apply_filters( "{$vct_prefix}_default_weight", 0 ) );
		        $data['custom_class'] = apply_filters( "{$vct_prefix}_{$hook_prefix}_class_{$filename_clean}", "vctm_{$hook_prefix}_{$filename_clean}" );
		        $data['content']    = apply_filters( "{$vct_prefix}_{$hook_prefix}_content_{$filename_clean}", file_get_contents( $filename ) );

		        $templates[] = $data;
		    }

		    return $templates;
		}

		/**
		 * Prettifies an ugly file name
		 *
		 * @param $name
		 * @return string
		 */
		function nflc_prettify_name( $name ) {
		    global $vct_prefix;

		    //Normalize spaces
		    $name = str_replace(array( '-', '_' ), ' ', $name );

		    $ret = '';
		    foreach( explode( ' ', $name ) as $word ) {
		        $ret .= ucfirst( $word ) . ' ';
			}

		    return rtrim( $ret );
		}

	}

	// Create new instance of class
	$nutrition_facts_label_creator = new Nutrition_Facts_Label_Creator();

} // If not class exists
?>